==> powerdevil-5.3.2.tar.xz: powerdevil-5.3.2/daemon/backends/upower/upowersuspendjob.h <==
/*  This file is part of the KDE project
    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
    Copyright (C) 2010 Alejandro Fiestas <alex@eyeos.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef UPOWERSUSPENDJOB_H
#define UPOWERSUSPENDJOB_H

#include <QDBusInterface>

#include <KJob>

#include "powerdevilbackendinterface.h"

class OrgFreedesktopUPowerInterface;

class UPowerSuspendJob : public KJob
{
    Q_OBJECT
public:
    UPowerSuspendJob(OrgFreedesktopUPowerInterface *upowerInterface,
                     PowerDevil::BackendInterface::SuspendMethod method,
                     PowerDevil::BackendInterface::SuspendMethods supported);
    virtual ~UPowerSuspendJob();

    void start() Q_DECL_OVERRIDE;

private Q_SLOTS:
    void doStart();
    void resumeDone();

private:
    OrgFreedesktopUPowerInterface *m_upowerInterface;
    PowerDevil::BackendInterface::SuspendMethod m_method;
    PowerDevil::BackendInterface::SuspendMethods m_supported;
};

#endif //UPOWERSUSPENDJOB_H

==> powerdevil-5.18.7.tar.xz: powerdevil-5.18.7/daemon/backends/upower/upowersuspendjob.h <==
/*  This file is part of the KDE project
    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
    Copyright (C) 2010 Alejandro Fiestas <alex@eyeos.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef UPOWERSUSPENDJOB_H
#define UPOWERSUSPENDJOB_H

#include <QDBusInterface>

#include <KJob>

#include "powerdevilbackendinterface.h"

class OrgFreedesktopUPowerInterface;

class UPowerSuspendJob : public KJob
{
    Q_OBJECT
public:
    UPowerSuspendJob(OrgFreedesktopUPowerInterface *upowerInterface,
                     PowerDevil::BackendInterface::SuspendMethod method,
                     PowerDevil::BackendInterface::SuspendMethods supported);
    ~UPowerSuspendJob() override;

    void start() override;

private Q_SLOTS:
    void doStart();
    void resumeDone();

private:
    OrgFreedesktopUPowerInterface *m_upowerInterface;
    PowerDevil::BackendInterface::SuspendMethod m_method;
    PowerDevil::BackendInterface::SuspendMethods m_supported;
};

#endif //UPOWERSUSPENDJOB_H
